@@ -11,6 +11,7 @@ from healthchain.fhir.helpers import (
     create_document_reference,
     create_single_attachment,
     create_resource_from_dict,
+    convert_prefetch_to_fhir_objects,
     add_provenance_metadata,
     add_coding_to_codeable_concept,
 )
@@ -22,6 +23,7 @@ from healthchain.fhir.bundle_helpers import (
     set_resources,
     merge_bundles,
     extract_resources,
+    count_resources,
 )
 
 __all__ = [
@@ -36,6 +38,7 @@ __all__ = [
     "create_document_reference",
     "create_single_attachment",
     "create_resource_from_dict",
+    "convert_prefetch_to_fhir_objects",
     # Resource modification
     "add_provenance_metadata",
     "add_coding_to_codeable_concept",
@@ -46,4 +49,5 @@ __all__ = [
     "set_resources",
     "merge_bundles",
     "extract_resources",
+    "count_resources",
 ]
