@@ -1,7 +1,7 @@
 import logging
 
 from contextlib import asynccontextmanager
-from typing import Any, Dict, Type
+from typing import Any, Dict, Optional, Type
 
 from fhir.resources.bundle import Bundle
 from fhir.resources.capabilitystatement import CapabilityStatement
@@ -173,6 +173,8 @@ class AsyncFHIRGateway(BaseFHIRGateway):
         source: str = None,
         add_provenance: bool = False,
         provenance_tag: str = None,
+        follow_pagination: bool = False,
+        max_pages: Optional[int] = None,
     ) -> Bundle:
         """
         Search for FHIR resources.
@@ -183,6 +185,8 @@ class AsyncFHIRGateway(BaseFHIRGateway):
             source: Source name to search in (uses first available if None)
             add_provenance: If True, automatically add provenance metadata to resources
             provenance_tag: Optional tag code for provenance (e.g., "aggregated", "transformed")
+            follow_pagination: If True, automatically fetch all pages
+            max_pages: Maximum number of pages to fetch (None for unlimited)
 
         Returns:
             Bundle containing search results
@@ -212,6 +216,37 @@ class AsyncFHIRGateway(BaseFHIRGateway):
             client_kwargs={"params": params},
         )
 
+        # Handle pagination if requested
+        if follow_pagination:
+            all_entries = bundle.entry or []
+            page_count = 1
+
+            while bundle.link:
+                next_link = next(
+                    (link for link in bundle.link if link.relation == "next"), None
+                )
+                if not next_link or (max_pages and page_count >= max_pages):
+                    break
+
+                # Extract the relative URL from the next link
+                # next_url = next_link.url.split("/")[-2:]  # Get resource_type/_search part
+                next_params = dict(
+                    pair.split("=") for pair in next_link.url.split("?")[1].split("&")
+                )
+
+                bundle = await self._execute_with_client(
+                    "search",
+                    source=source,
+                    resource_type=resource_type,
+                    client_args=(resource_type, next_params),
+                )
+
+                if bundle.entry:
+                    all_entries.extend(bundle.entry)
+                page_count += 1
+
+            bundle.entry = all_entries
+
         if add_provenance and bundle.entry:
             source_name = source or next(iter(self.connection_manager.sources.keys()))
             for entry in bundle.entry:
