@@ -13,7 +13,6 @@ from .responses import (
     CDSServiceInformation,
     CdaResponse,
 )
-from .hooks import Prefetch
 
 __all__ = [
     "CDSRequest",
@@ -31,5 +30,4 @@ __all__ = [
     "CDSResponse",
     "CdaRequest",
     "CdaResponse",
-    "Prefetch",
 ]
