@@ -2,7 +2,6 @@ from .patientview import PatientViewContext
 from .encounterdischarge import EncounterDischargeContext
 from .orderselect import OrderSelectContext
 from .ordersign import OrderSignContext
-from .prefetch import Prefetch
 
 
 __all__ = [
@@ -10,5 +9,4 @@ __all__ = [
     "EncounterDischargeContext",
     "OrderSelectContext",
     "OrderSignContext",
-    "Prefetch",
 ]
